@@ -86,8 +86,8 @@ KlamDB::KlamDB( TQWidget* parent, const char* name, bool modal, WFlags fl )
 
     VirusList = new TDEListView( privateLayoutWidget, "VirusList" );
     VirusList->addColumn( i18n( "All Known Viruses" ),150 );
-    connect(VirusList, SIGNAL( doubleClicked( TQListViewItem * , const TQPoint &, int ) ),
-                    this, SLOT(slotOpenTab(TQListViewItem * , const TQPoint &, int )) );
+    connect(VirusList, TQ_SIGNAL( doubleClicked( TQListViewItem * , const TQPoint &, int ) ),
+                    this, TQ_SLOT(slotOpenTab(TQListViewItem * , const TQPoint &, int )) );
 
     menu = new TQPopupMenu( VirusList );
 
@@ -106,22 +106,22 @@ KlamDB::KlamDB( TQWidget* parent, const char* name, bool modal, WFlags fl )
     else
       ticon = TQPixmap( iconPath );
 
-    menu->insertItem(ticon, i18n("Search with Trend Micro"), this,SLOT(slotTrendMicro()) );
-    menu->insertItem(gicon, i18n("Search with Google"), this,SLOT(slotGoogle()) );
+    menu->insertItem(ticon, i18n("Search with Trend Micro"), this,TQ_SLOT(slotTrendMicro()) );
+    menu->insertItem(gicon, i18n("Search with Google"), this,TQ_SLOT(slotGoogle()) );
 
     googlePrefix = TQString::fromAscii("http://www.google.com/search?ie=ISO-8859-1&q=");
     tMicroPrefix = TQString::fromAscii("https://www.trendmicro.com/vinfo/us/threat-encyclopedia/search/");
 
-    connect(VirusList, SIGNAL( contextMenuRequested( TQListViewItem *, const TQPoint& , int ) ), 
-    this, SLOT( slotRMB( TQListViewItem *, const TQPoint &, int ) ) );
+    connect(VirusList, TQ_SIGNAL( contextMenuRequested( TQListViewItem *, const TQPoint& , int ) ), 
+    this, TQ_SLOT( slotRMB( TQListViewItem *, const TQPoint &, int ) ) );
 
     kLineEdit1 = new TDEListViewSearchLine( (TQWidget *)searchToolBar, VirusList,"klinedit1");
     TQValueList<int> columns;
         columns.append(0);
     kLineEdit1->setSearchColumns(columns);
     kLineEdit1->setMaxLength(2);
-    connect(button, SIGNAL( clicked() ),
-                    kLineEdit1, SLOT(clear()) );
+    connect(button, TQ_SIGNAL( clicked() ),
+                    kLineEdit1, TQ_SLOT(clear()) );
 
     dblayout->addWidget( searchToolBar, 0, 0 );
     
@@ -839,8 +839,11 @@ void KlamDB::addVirusName(char *start)
 
 unsigned int  KlamDB::getSigNos()
 {
-        
+#   if defined(USE_CL_ERROR_T)
+    cl_error_t ret  = CL_CLEAN;
+#   else
     unsigned int ret= 0;
+#   endif
     unsigned int no = 0;
     struct cl_engine *engine = NULL;
     TQStringList lastDownloadPaths;
@@ -869,14 +872,14 @@ unsigned int  KlamDB::getSigNos()
 void KlamDB::slotOpenTab(TQListViewItem * item, const TQPoint& , int )
 {
     PageViewer* page = new PageViewer(this, "page");
-    //connect( m_part, SIGNAL(signalSettingsChanged()), page, SLOT(slotPaletteOrFontChanged()));
+    //connect( m_part, TQ_SIGNAL(signalSettingsChanged()), page, TQ_SLOT(slotPaletteOrFontChanged()));
     
-    //connect( page, SIGNAL(setTabIcon(const TQPixmap&)),
-    //        this, SLOT(setTabIcon(const TQPixmap&)));
-    //connect( page, SIGNAL(setWindowCaption (const TQString &)),
-    //        this, SLOT(slotTabCaption (const TQString &)) );
-    connect( page, SIGNAL(urlClicked(const KURL &,bool)),
-            this, SLOT(slotOpenTabPlain(const KURL &,bool)) );
+    //connect( page, TQ_SIGNAL(setTabIcon(const TQPixmap&)),
+    //        this, TQ_SLOT(setTabIcon(const TQPixmap&)));
+    //connect( page, TQ_SIGNAL(setWindowCaption (const TQString &)),
+    //        this, TQ_SLOT(slotTabCaption (const TQString &)) );
+    connect( page, TQ_SIGNAL(urlClicked(const KURL &,bool)),
+            this, TQ_SLOT(slotOpenTabPlain(const KURL &,bool)) );
 
     TQString url = item->text(0);
     
@@ -897,14 +900,14 @@ void KlamDB::slotOpenTab(TQListViewItem * item, const TQPoint& , int )
 void KlamDB::slotOpenTabPlain(const KURL& url, bool background)
 {
     PageViewer* page = new PageViewer(this, "page");
-    //connect( m_part, SIGNAL(signalSettingsChanged()), page, SLOT(slotPaletteOrFontChanged()));
+    //connect( m_part, TQ_SIGNAL(signalSettingsChanged()), page, TQ_SLOT(slotPaletteOrFontChanged()));
     
-/*    connect( page, SIGNAL(setTabIcon(const TQPixmap&)),
-            this, SLOT(setTabIcon(const TQPixmap&)));*/
-    connect( page, SIGNAL(setWindowCaption (const TQString &)),
-            this, SLOT(slotTabCaption (const TQString &)) );
-    connect( page, SIGNAL(urlClicked(const KURL &,bool)),
-            this, SLOT(slotOpenTabPlain(const KURL &,bool)) );
+/*    connect( page, TQ_SIGNAL(setTabIcon(const TQPixmap&)),
+            this, TQ_SLOT(setTabIcon(const TQPixmap&)));*/
+    connect( page, TQ_SIGNAL(setWindowCaption (const TQString &)),
+            this, TQ_SLOT(slotTabCaption (const TQString &)) );
+    connect( page, TQ_SIGNAL(urlClicked(const KURL &,bool)),
+            this, TQ_SLOT(slotOpenTabPlain(const KURL &,bool)) );
 
     Frame *frame=new Frame(this, page, page->widget(), i18n("Untitled"));
     //connectFrame(frame);
