@@ -102,10 +102,10 @@ Kuarantine::Kuarantine(TQWidget *parent, const char *name)
     dir_layout->addWidget(dir_combo);
     dir_label->setBuddy(dir_combo);
     
-    connect( dir_combo, SIGNAL(urlSelected(const TQString &)),
-        SLOT(updateLastQuarLocations()) );
-    connect( dir_combo, SIGNAL(textChanged(const TQString &)),
-        SLOT(updateLastQuarLocations()) );
+    connect( dir_combo, TQ_SIGNAL(urlSelected(const TQString &)),
+        TQ_SLOT(updateLastQuarLocations()) );
+    connect( dir_combo, TQ_SIGNAL(textChanged(const TQString &)),
+        TQ_SLOT(updateLastQuarLocations()) );
 
 
 
@@ -145,8 +145,8 @@ Kuarantine::Kuarantine(TQWidget *parent, const char *name)
 
     qmenu = new TQPopupMenu( currentbox );
 
-        connect(currentbox, SIGNAL( contextMenuRequested( TQListViewItem *, const TQPoint& , int ) ), 
-        this, SLOT( slotRMB( TQListViewItem *, const TQPoint &, int ) ) );
+        connect(currentbox, TQ_SIGNAL( contextMenuRequested( TQListViewItem *, const TQPoint& , int ) ), 
+        this, TQ_SLOT( slotRMB( TQListViewItem *, const TQPoint &, int ) ) );
 
     dir_layout2->addWidget(currentbox);
     
@@ -168,13 +168,13 @@ Kuarantine::Kuarantine(TQWidget *parent, const char *name)
     dir_layout2->addWidget(actionbox);
 
 
-    connect( refresh_button, SIGNAL(clicked()),
-        SLOT(refresh()) );
+    connect( refresh_button, TQ_SIGNAL(clicked()),
+        TQ_SLOT(refresh()) );
 
-    connect( search_button, SIGNAL(clicked()),
-        SLOT(slotSearch()) );
-    connect( cancel_button, SIGNAL(clicked()),
-        SLOT(slotCancel()) );
+    connect( search_button, TQ_SIGNAL(clicked()),
+        TQ_SLOT(slotSearch()) );
+    connect( cancel_button, TQ_SIGNAL(clicked()),
+        TQ_SLOT(slotCancel()) );
 
 
 
@@ -213,8 +213,8 @@ Kuarantine::Kuarantine(TQWidget *parent, const char *name)
 
     hmenu = new TQPopupMenu( historybox );
 
-        connect(historybox, SIGNAL( contextMenuRequested( TQListViewItem *, const TQPoint& , int ) ), 
-        this, SLOT( slotRMB( TQListViewItem *, const TQPoint &, int ) ) );
+        connect(historybox, TQ_SIGNAL( contextMenuRequested( TQListViewItem *, const TQPoint& , int ) ), 
+        this, TQ_SLOT( slotRMB( TQListViewItem *, const TQPoint &, int ) ) );
 
     dir_layout3->addWidget(historybox);
     //layout->addMultiCellWidget(historybox, 2, 2, 0, 2);
@@ -232,10 +232,10 @@ Kuarantine::Kuarantine(TQWidget *parent, const char *name)
 
     refreshhistory();
 
-    connect( search_button3, SIGNAL(clicked()),
-        SLOT(slotClearHistory()) );
-    connect( cancel_button3, SIGNAL(clicked()),
-        SLOT(slotDeleteHistory()) );
+    connect( search_button3, TQ_SIGNAL(clicked()),
+        TQ_SLOT(slotClearHistory()) );
+    connect( cancel_button3, TQ_SIGNAL(clicked()),
+        TQ_SLOT(slotDeleteHistory()) );
 
     
     
@@ -637,14 +637,14 @@ void Kuarantine::slotRMB( TQListViewItem* Item, const TQPoint & point, int )
 
     if (Item->listView() == currentbox){
         qmenu->clear();
-        qmenu->insertItem( ticon,i18n("Search for %1 with Trend Micro").arg(Item->text(1)), this, SLOT(slotTrendMicroCurrent()) );
-        qmenu->insertItem( gicon,i18n("Search for %1 with Google").arg(Item->text(1)), this, SLOT(slotGoogleCurrent()) );
+        qmenu->insertItem( ticon,i18n("Search for %1 with Trend Micro").arg(Item->text(1)), this, TQ_SLOT(slotTrendMicroCurrent()) );
+        qmenu->insertItem( gicon,i18n("Search for %1 with Google").arg(Item->text(1)), this, TQ_SLOT(slotGoogleCurrent()) );
     
         qmenu->popup( point );
     }else if (Item->listView() == historybox){
         hmenu->clear();
-        hmenu->insertItem( ticon,i18n("Search for %1 with Trend Micro").arg(Item->text(1)), this, SLOT(slotTrendMicroHistory()) );
-        hmenu->insertItem( gicon,i18n("Search for %1 with Google").arg(Item->text(1)), this, SLOT(slotGoogleHistory()) );
+        hmenu->insertItem( ticon,i18n("Search for %1 with Trend Micro").arg(Item->text(1)), this, TQ_SLOT(slotTrendMicroHistory()) );
+        hmenu->insertItem( gicon,i18n("Search for %1 with Google").arg(Item->text(1)), this, TQ_SLOT(slotGoogleHistory()) );
     
         hmenu->popup( point );
     }
