@@ -70,15 +70,15 @@ ScanViewer::ScanViewer(TQWidget *parent, const char *name)
     resultview->setAllColumnsShowFocus(true);
     layout->addMultiCellWidget(resultview, 2, 2, 0, 2);
 
-    connect( resultview, SIGNAL(onItem ( TQListViewItem * )),
-        SLOT(slotOnItem ( TQListViewItem * )));
-    connect( resultview, SIGNAL(onViewport (  )),
-        SLOT(slotOffItem ( )));
+    connect( resultview, TQ_SIGNAL(onItem ( TQListViewItem * )),
+        TQ_SLOT(slotOnItem ( TQListViewItem * )));
+    connect( resultview, TQ_SIGNAL(onViewport (  )),
+        TQ_SLOT(slotOffItem ( )));
 
     menu = new TQPopupMenu( resultview );
 
-        connect(resultview, SIGNAL( contextMenuRequested( TQListViewItem *, const TQPoint& , int ) ),
-        this, SLOT( slotRMB( TQListViewItem *, const TQPoint &, int ) ) );
+        connect(resultview, TQ_SIGNAL( contextMenuRequested( TQListViewItem *, const TQPoint& , int ) ),
+        this, TQ_SLOT( slotRMB( TQListViewItem *, const TQPoint &, int ) ) );
 
     status_frame = new TQFrame(this);
     status_frame->setFrameStyle(TQFrame::Panel | TQFrame::Sunken);
@@ -125,8 +125,8 @@ ScanViewer::ScanViewer(TQWidget *parent, const char *name)
     scan_time->show();
 
     //status_frame->setPaletteBackgroundColor(TQColor::Yellow);
-    connect( scan_time, SIGNAL(clicked()),
-        SLOT(slotCancelScanTime()) );
+    connect( scan_time, TQ_SIGNAL(clicked()),
+        TQ_SLOT(slotCancelScanTime()) );
 
 
 
@@ -509,17 +509,17 @@ void ScanViewer::slotScan(const TQStringList & filepattern, int mode, bool recur
     *childproc << "'" + m_filepattern.join("' '") + "'";
 
 
-/*    connect( childproc, SIGNAL(processExited(TDEProcess *)),
-        SLOT(childExited()) );
-    connect( childproc, SIGNAL(receivedStdout(TDEProcess *, char *, int)),
-        SLOT(receivedOutput(TDEProcess *, char *, int)) );
+/*    connect( childproc, TQ_SIGNAL(processExited(TDEProcess *)),
+        TQ_SLOT(childExited()) );
+    connect( childproc, TQ_SIGNAL(receivedStdout(TDEProcess *, char *, int)),
+        TQ_SLOT(receivedOutput(TDEProcess *, char *, int)) );
     childproc->start(TDEProcess::NotifyOnExit, TDEProcess::Stdout);*/
 
-    connect( childproc, SIGNAL(readReady(KProcIO *)),
-        SLOT(receivedOutput(KProcIO *)) );
+    connect( childproc, TQ_SIGNAL(readReady(KProcIO *)),
+        TQ_SLOT(receivedOutput(KProcIO *)) );
     childproc->start(KProcIO::NotifyOnExit);
-    connect( childproc, SIGNAL(processExited(TDEProcess *)),
-            SLOT(childExited()) );
+    connect( childproc, TQ_SIGNAL(processExited(TDEProcess *)),
+            TQ_SLOT(childExited()) );
 
     scanInProgress = TRUE;
 
@@ -592,7 +592,7 @@ void ScanViewer::childExited()
 
     if (status == 0){
     	tdemain->_tray->setPixmap(KSystemTray::loadIcon("klamav_scan_safe"));
-        TQTimer::singleShot( 10000, this, SLOT(resetSysTray()) );
+        TQTimer::singleShot( 10000, this, TQ_SLOT(resetSysTray()) );
         if (!(errorsEncountered))
             KNotifyClient::event(tdemain->_tray->winId(),"Scan Complete - No Virus Found", i18n("Scan Complete - No Viruses Found!"));
         else
@@ -778,11 +778,11 @@ void ScanViewer::slotRMB( TQListViewItem* Item, const TQPoint & point, int )
           vlicon = TQPixmap( iconPath );
 
     menu->clear();
-        menu->insertItem( "Quarantine Selected", this,SLOT(slotQuarantineSelected()) );
+        menu->insertItem( "Quarantine Selected", this,TQ_SLOT(slotQuarantineSelected()) );
 
-        menu->insertItem( ticon,i18n("Search for %1 with Trend Micro").arg(Item->text(1)), this, SLOT(slotTrendMicro()) );
+        menu->insertItem( ticon,i18n("Search for %1 with Trend Micro").arg(Item->text(1)), this, TQ_SLOT(slotTrendMicro()) );
 
-        menu->insertItem( gicon,i18n("Search for %1 with Google").arg(Item->text(1)), this, SLOT(slotGoogle()) );
+        menu->insertItem( gicon,i18n("Search for %1 with Google").arg(Item->text(1)), this, TQ_SLOT(slotGoogle()) );
         menu->popup( point );
      }
 }
@@ -921,7 +921,7 @@ void ScanViewer::startProgressDialog( const TQString & text )
     progressDialog->show();
 
     timer = new TQTimer( this );
-    connect( timer, SIGNAL( timeout() ), this, SLOT( slotProg() ) );
+    connect( timer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( slotProg() ) );
 
     timer->start( 200, FALSE );
 }
